
.. _io/index:

Input/Output
************

.. currentmodule:: jgrapht.io

The JGraphT contains a large collection of importers/exporters. They can be used 
to read/write graph from files and strings.

.. toctree::
   :maxdepth: 2

   importers
   exporters
   edgelist

